@@ -154,7 +154,9 @@ proc Fcache_FolderName { folder } {
 	set key "seqcount,$folder,$mhProfile(unseen-sequence)"
 	if [ info exists flist($key)] {
 	    set num $flist($key)
-	    set fname "$fname:$num"
+            if { $num > 0} {
+	      set fname "$fname:$num"
+           }
 	}
     }
     return $fname
@@ -254,13 +256,13 @@ proc Fcache_Folder { folder } {
 	} else {
 	    lappend fcache(folders) $folder
 	    lappend fcache(LRU) $folder
-	    FcacheLRU
 	}
-	Fcache_Display
     } else {
 	set fcache(LRU) [lreplace $fcache(LRU) $ix $ix]
 	lappend fcache(LRU) $folder
     }
+    FcacheLRU
+    Fcache_Display
 }
 proc FcacheLRU {} {
     global fcache fdisp
