@@ -24,7 +24,7 @@
 # any specification.
 
 proc Flag_Init {} {
-    global flag exmh
+    global flag exmh flist mhProfile
     set flag(state) init
     
     # Note - if you change the icon, there is some code in ExmhArgv
@@ -32,7 +32,7 @@ proc Flag_Init {} {
     Preferences_Resource flag(iconup) iconUpBitmap flagup.bitmap
     Preferences_Resource flag(icondown) iconDownBitmap flagdown.bitmap
     Preferences_Resource flag(iconspool) iconSpoolBitmap flagspool.bitmap
-    Preferences_Resource flag(labelup) iconUpLabel {$flist(newMsgs) Unseen}
+    Preferences_Resource flag(labelup) iconUpLabel {$flist(totalcount,$mhProfile(unseen-sequence)) Unseen}
     Preferences_Resource flag(labeldown) iconDownLabel exmh
     Preferences_Resource flag(labelspool) iconSpoolLabel {$exmh(numUnInced) Spooled}
     Preferences_Resource flag(iconupmask) iconUpMask flagup.mask
@@ -68,6 +68,32 @@ proc Flag_Init {} {
 	}
     }
     FlagInner down icondown labeldown
+    # Call explicitly from FlistDone
+#    trace variable flist(totalcount,$mhProfile(unseen-sequence)) wu Flag_Trace
+}
+proc Flag_Trace args {
+    global flist mhProfile
+
+    if {[info exists flist(oldtotalcount,$mhProfile(unseen-sequence))]} {
+	set oldtotal $flist(oldtotalcount,$mhProfile(unseen-sequence))
+    } else {
+	set oldtotal 0
+    }
+    set delta [expr {$flist(totalcount,$mhProfile(unseen-sequence)) - $oldtotal}]
+    set flist(oldtotalcount,$mhProfile(unseen-sequence)) $flist(totalcount,$mhProfile(unseen-sequence))
+    if {($delta > 0) && ($flist(totalcount,$mhProfile(unseen-sequence)) > 0)} {
+	set count $flist(totalcount,$mhProfile(unseen-sequence))
+	if {$count == 1} {set m ""} else {set m "s"}
+	set len [llength $flist($mhProfile(unseen-sequence))]
+	if {$len == 1} {set f ""} else {set f "s"}
+	Exmh_Status "$count unseen message$m in $len folder$f"
+	Flag_NewMail
+	Sound_Feedback $delta
+    }
+    if {($flist(totalcount,$mhProfile(unseen-sequence)) <= 0) && ($delta != 0)} {
+	Flag_NoUnseen
+	Exmh_Status "No unseen messages"
+    }
 }
 proc Flag_NewMail { {folder {}} } {
     FlagInner up iconup labelup
@@ -75,8 +101,9 @@ proc Flag_NewMail { {folder {}} } {
 # Flag_MsgSeen drops the flag but retains the proper label
 # This is called after viewing a message
 proc Flag_MsgSeen { {folder {}} } {
-    global flist
-    if {$flist(newMsgs) > 0} {
+    global flist mhProfile
+    if {[info exists flist(totalcount,$mhProfile(unseen-sequence))] &&
+	$flist(totalcount,$mhProfile(unseen-sequence)) > 0} {
 	FlagInner spool iconspool labelup
     } else {
 	FlagInner down icondown labeldown
