@@ -321,7 +321,7 @@ proc Mh_AnnoCleanup { draftID } {
 
 proc Mh_Folder { f } {
     if {[catch {MhExec folder +$f < /dev/null} info]} {
-	Exmh_Debug $info
+	Exmh_Debug Mh_Folder caught $info
 	return {}
     } else {
 	if {[regexp {\+[^0-9]+ ([0-9]+) [^(]*\(([^)]+)\)} $info x total range]} {
@@ -394,6 +394,7 @@ proc Mh_SetCur { folder msgid } {
 	($mhPriv(cur,$folder) == $msgid)} {
 	return
     }
+    Mh_SequenceUpdate $folder replace cur $msgid
     Seq_Set $folder cur $msgid
     set mhPriv(cur,$folder) $msgid
 }
@@ -436,7 +437,7 @@ proc MhReadSeqs {folder seqsvar} {
 		}
 	    }
 	    if {[catch {open $filename r} in] == 0} {
-		Exmh_Debug Reading $filename
+		Exmh_Debug MhReadSeqs Reading $filename
 		set old [read $in]
 		close $in
 		foreach line [split $old \n] {
@@ -480,7 +481,7 @@ proc MhReadSeqs {folder seqsvar} {
 		}
 	    }
 	    if {[catch {open $filename r} in] == 0} {
-		Exmh_Debug Reading $filename
+		Exmh_Debug MhReadSeq Reading $filename
 		set old [read $in]
 		close $in
 		foreach line [split $old \n] {
@@ -582,7 +583,9 @@ proc Mh_SequenceUpdate { folder how seq {msgids {}} {which public}} {
 	    Exmh_Debug "    : [info level $l]"
 	}
     }
-    array unset seqs
+    if {[info exist seqs]} {
+      unset seqs
+    }
     foreach elem [array names mhPriv] {
 	set indices [split $elem ,]
 	if {[lindex $indices 0] == {mode}} {
@@ -1209,3 +1212,8 @@ proc Mh_FindFile { filename } {
     return ""
     
 }
+# exmh-2.5 APIs
+# Mh_ClearCur 
+# Mh_MarkSeen
+# Mh_MarkUnseen
+# Mh_Unseen 
