@@ -73,7 +73,7 @@ folder width."
 "Sequences to never display in the sequences window."
     }
 
-    { seqwin(alwaysshow) seqAlwaysShow {unseen} {Always Show Sequences}
+    { seqwin(alwaysshow) seqAlwaysShow {} {Always Show Sequences}
 "Sequences to always display, even when they're empty."
     }
 
@@ -164,13 +164,11 @@ Compose:       Starts a mail composition"
     trace variable seqwin(alwaysshow) w SeqWinFixShowList
     trace variable seqwin(orientation) w SeqWinFixOrientation
 
-    if {$seqwin(on)} {
-      SeqWinToggle
-    }
+    SeqWin_Init
 }
 proc Seq_Trace {array elem op} {
     global flist seqwin
-
+Exmh_Debug "Seq_Trace $array $elem $op"
     set indices [split $elem ,]
     set var [lindex $indices 0]
     if {$var == {seqcount}} {
@@ -313,11 +311,15 @@ proc Seq_Add {folder seq msgids} {
 	Fdisp_HighlightUnseen $folder
     }
 }
+
 # Set the contents of a sequence for a folder.
+# This no longer synchronizes with the file system -
+# use Mh_SequenceUpdate explicitly for that.
+
 proc Seq_Set {folder seq msgids} {
     global flist exmh mhProfile
-#   catch {MhExec mark +$folder $msgids -seq $seq -zero}
-    Mh_SequenceUpdate $folder replace $seq $msgids
+#    catch {MhExec mark +$folder $msgids -seq $seq -zero}
+#    Mh_SequenceUpdate $folder replace $seq $msgids
     if [info exists flist(seqcount,$folder,$seq)] {
 	set oldnum $flist(seqcount,$folder,$seq)
     } else {
